==> PathOfBuilding-1.4.155.zip: Data/Uniques/axe.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Weapon: One Handed Axe
[[
Dreadarc
Cleaver
Upgrade: Upgrades to unique{Dreadsurge} via prophecy{Burning Dread}
Variant: Pre 2.6.0
Variant: Current
Requires Level 16, 48 Str
Adds (5-15) to (20-25) Physical Damage
Adds (5-15) to (20-25) Fire Damage
5% increased Movement Speed
(7-10)% Increased Attack Speed
+(15-25)% to Fire Resistance
{variant:1}Curse Enemies with Flammability on Hit
{variant:2}Curse Enemies with level 10 Flammability on Hit
]],[[
Dreadsurge
Cleaver
Source: Upgraded from unique{Dreadarc} via prophecy{Burning Dread}
Requires Level 60
Adds (5-15) to (20-25) Physical Damage
Adds (223-250) to (264-280) Fire Damage
5% increased Movement Speed
(7-10)% increased Attack Speed
+(15-25)% to Fire Resistance
Hits ignore Enemy Monster Fire Resistance while you are Ignited
]],[[
Dyadus
Infernal Axe
Variant: Pre 2.6.0
Variant: Pre 3.3.0
Variant: Current
Requires Level 69, 158 Str, 76 Dex
{variant:1}Adds (170-190) to (200-220) Fire Damage in Main Hand
{variant:2,3}Adds (255-285) to (300-330) Fire Damage in Main Hand
{variant:1}Adds (170-190) to (200-220) Cold Damage in Off Hand
{variant:2,3}Adds (255-285) to (300-330) Cold Damage in Off Hand
(10-15)% increased Attack Speed
{variant:1}Enemies Chilled by you take 40% increased Burning Damage
{variant:2}Enemies Chilled by you take 100% increased Burning Damage
{variant:3}100% increased Damage with Ignites inflicted on Chilled Enemies
25% Chance to Ignite when in Main Hand
{variant:1}100% increased Chill Duration on Enemies when in Off Hand
{variant:2,3}Chill Enemies for 1 second on Hit with this Weapon when in Off Hand
]],[[
The Screaming Eagle
Jade Hatchet
Upgrade: Upgrades to unique{The Gryphon} via prophecy{The Apex Predator}
Variant: Pre 2.0.0
Variant: Current
Requires Level 6, 21 Str
{variant:1}Adds (8-12) to (18-22) Physical Damage
{variant:2}Adds (10-15) to (25-30) Physical Damage
+(10-15) to maximum Life
+(5-7) Life gained on Kill
10% increased Movement Speed
Socketed Gems are supported by level 2 Chance to Flee
]],[[
The Gryphon
Jade Hatchet
Source: Upgraded from unique{The Screaming Eagle} via prophecy{The Apex Predator}
Requires Level 32, 21 Str
Socketed Gems are supported by level 2 Chance to Flee
(170-190)% increased Physical Damage
Adds (10-15) to (25-30) Physical Damage
+(10-15) to maximum Life
+(5-7) Life gained on Kill
10% increased Movement Speed
15% increased Movement Speed if you've Killed Recently
]],[[
Jack, the Axe
Vaal Hatchet
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 65, 140 Str, 86 Dex
(90-110)% increased Physical Damage
Adds (11-14) to (18-23) Physical Damage
(10-15)% increased Attack Speed
2% of Physical Attack Damage Leeched as Life
50% reduced Life Leeched per second
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
]],[[
Moonbender's Wing
Tomahawk
Requires Level 39, 81 Str, 56 Dex
(70-90)% increased Physical Damage
Adds (5-9) to (13-17) Physical Damage
(30-50)% increased Critical Strike Chance
25% of Physical Damage Converted to Cold Damage
25% of Physical Damage Converted to Lightning Damage
Grants level 1 Lightning Warp Skill
]],[[
Relentless Fury
Decorative Axe
Variant: Pre 2.6.0
Variant: Current
Requires Level 29, 80 Str, 23 Dex
(60-80)% increased Physical Damage
Adds (3-5) to (7-10) Physical Damage
{variant:1}0.6% of Physical Attack Damage Leeched as Life
{variant:2}2% of Physical Attack Damage Leeched as Life
Culling Strike
You gain Onslaught for 3 seconds on Culling Strike
Cannot be Chilled while you have Onslaught
]],[[
Rigwald's Savagery
Royal Axe
League: Talisman Standard, Talisman Hardcore
Source: Drops from unique{Rigwald, the Wolven King} (Level 75+)
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 67, 167 Str, 57 Dex
Adds (50-70) to (135-165) Physical Damage
40% increased Physical Weapon Damage while Dual Wielding
(10-15)% increased Attack Speed
35% increased Attack Speed with Swords
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
]],[[
Soul Taker
Siege Axe
Variant: Pre 1.0.0
Variant: Current
Requires Level 59, 119 Str, 82 Dex
{variant:1}(160-200)% increased Physical Damage
{variant:2}(100-140)% increased Physical Damage
Adds 10 to 20 Physical Damage
(20-25)% increased Attack Speed
+(20-25)% to Cold Resistance
Insufficient Mana doesn't prevent your Melee Attacks
Your Physical Damage can Chill
]],
-- Weapon: Two Handed Axe
[[
Atziri's Disfavour
Vaal Axe
Source: Drops from unique{Atziri, Queen of the Vaal} in normal{The Alluring Abyss}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 75, 158 Str, 76 Dex
+2 to Level of Socketed Support Gems
Adds (220-235) to (270-290) Physical Damage
(12-16)% increased Attack Speed
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
+2 to Weapon range
]],[[
The Blood Reaper
Headsman Axe
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 45, 99 Str, 57 Dex
{variant:1}(100-120)% increased Physical Damage
{variant:2}(180-200)% increased Physical Damage
+100 to maximum Life
10.0 Life Regenerated per second
1% of Physical Attack Damage Leeched as Life
50% increased Mana Cost of Skills
{variant:1}Causes Bleeding on Hit
{variant:2}50% chance to cause Bleeding on Hit
]],[[
Debeon's Dirge
Despot Axe
Requires Level 66, 140 Str, 86 Dex
Adds (310-350) to (460-500) Cold Damage
15% increased Movement Speed if you've used a Warcry Recently
150% increased Elemental Damage if you've used a Warcry Recently
Warcries Knock Enemies Back in an Area
]],[[
The Harvest
Jasper Chopper
League: Beyond
Requires Level 37, 100 Str, 29 Dex
(120-140)% increased Physical Damage
1.2% of Damage Leeched as Life on Critical Strike
3% increased Global Critical Strike Chance per Level
Gain Flask Charges when you deal a Critical Strike
]],[[
Hezmana's Bloodlust
Vaal Axe
Requires Level 64, 158 Str, 76 Dex
(150-170)% increased Physical Damage
Adds (7-12) to (16-25) Physical Damage
1% of Physical Attack Damage Leeched as Life
Attacks have Blood Magic
]],[[
Kaom's Primacy
Karui Chopper
League: Legion
Source: Drops from normal{Karui} legion
Variant: Pre 3.7.0
Variant: Current
Requires Level 58, 151 Str, 43 Dex
(160-220)% increased Physical Damage
{variant:1}Adds (16-21) to (32-38) Fire Damage
+20 Life gained on Kill
+(150-250) to Accuracy Rating
Culling Strike
{variant:2}Gain 1 Rage on Critical Hit with attacks, no more than once every 0.5 seconds
{variant:2}Gain 1% of Physical Damage as Extra Fire Damage per 1 Rage
]],[[
Kingmaker
Despot Axe
Source: Vendor recipe
Variant: Pre 2.6.0
Variant: Current
Requires Level 66, 140 Str, 86 Dex
(200-250)% increased Physical Damage
(7-12)% increased Attack Speed
{variant:2}(30-40)% increased Critical Strike Chance
{variant:1}+(100-150) to maximum Mana
{variant:2}Insufficient Mana doesn't prevent your Melee Attacks
Nearby Allies have 30% increased Item Rarity
{variant:1}Nearby Allies' spells have Culling Strike
{variant:2}Nearby Allies have Culling Strike
]],[[
Kitava's Feast
Void Axe
Variant: Pre 3.5.0
Variant: Current
Requires Level 68, 149 Str, 76 Dex
Socketed Gems are supported by level 25 Melee Splash
{variant:1}(250-300)% increased Physical Damage
{variant:2}(265-330)% increased Physical Damage
1% of Physical Attack Damage Leeched as Life
1% of Physical Attack Damage Leeched as Mana
Recover 5% of Maximum Life on Kill
Enemies you hit are destroyed on Kill
]],[[
Limbsplit
Woodsplitter
Upgrade: Upgrades to unique{The Cauteriser} via prophecy{Severed Limbs}
Requires Level 13, 36 Str, 17 Dex
+1 to Level of Socketed Strength Gems
(80-100)% increased Physical Damage
Adds 5 to 10 Physical Damage
+(15-30) to Strength
Culling Strike
]],[[
The Cauteriser
Woodsplitter
Source: Upgraded from unique{Limbsplit} using prophecy{Severed Limbs}
Requires Level 40, 36 Str, 17 Dex
+1 to Level of Socketed Strength Gems
(80-100)% increased Physical Damage
Adds (35-45) to (80-90) Physical Damage
+(15-30) to Strength
Gain 70% of Physical Damage as Extra Fire Damage
Culling Strike
]],[[
Ngamahu's Flame
Abyssal Axe
Requires Level 55, 128 Str, 60 Dex
(190-230)% increased Physical Damage
(8-12)% increased Attack Speed
50% of Physical Damage Converted to Fire Damage
Damage Penetrates 20% Fire Resistance
20% chance to attack with Level 16 Molten Burst on Melee Hit
]],[[
Reaper's Pursuit
Shadow Axe
Requires Level 33, 80 Str, 37 Dex
(100-125)% increased Physical Damage
+10 Life Gained on Kill
(30-40)% increased Rarity of Items found
15% increased Movement Speed when on Full Life
Culling Strike
Hits can't be Evaded
]],[[
Sinvicta's Mettle
Ezomyte Axe
Requires Level 62
(200-212)% increased Physical Damage
(8-12)% increased Attack Speed
Rampage
2% increased Area of Effect per 25 Rampage Kills
Gain a Frenzy Charge on every 50th Rampage Kill
]],[[
Uul-Netol's Kiss
Labrys
League: Breach
Source: Drops in Uul-Netol Breach or from unique{Uul-Netol, Unburdened Flesh}
Upgrade: Upgrades to unique{Uul-Netol's Embrace} using currency{Blessing of Uul-Netol}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 49, 122 Str, 53 Dex
(140-170)% increased Physical Damage
15% reduced Attack Speed
25% chance to Curse Enemies with level 10 Vulnerability on Hit
{variant:1}Attacks Cause Bleeding when Hitting Cursed Enemies
{variant:2}Attacks have 25% chance to cause Bleeding when Hitting Cursed Enemies
]],[[
Uul-Netol's Embrace
Vaal Axe
League: Breach
Source: Upgraded from unique{Uul-Netol's Kiss} using currency{Blessing of Uul-Netol}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 64, 158 Str, 76 Dex
(280-320)% increased Physical Damage
(30-25)% reduced Attack Speed
{variant:1}Attacks Cause Bleeding when Hitting Cursed Enemies
{variant:2}Attacks have 25% chance to cause Bleeding when Hitting Cursed Enemies
Trigger Level 20 Bone Nova when you Kill a Bleeding Enemy
]],[[
Wideswing
Poleaxe
Variant: {2_6}Pre 3.7.0
Variant: Current
Requires Level 18, 44 Str, 25 Dex
Socketed Gems are Supported by level 20 Increased Area of Effect
(120-160)% increased Physical Damage
+10 to Strength
{variant:1}+(50-80) to Accuracy Rating
{variant:2}+(120-150) to Accuracy Rating
+10 Mana Gained on Kill
+2 to Weapon range
]],[[
Wings of Entropy
Sundering Axe
Variant: Pre 1.3.0
Variant: Pre 2.0.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 60, 149 Str, 76 Dex
{variant:1,2,3}25% of Block Chance applied to Spells
{variant:4}+7% chance to Block Spell Damage
{variant:1}10% additional Chance to Block while Dual Wielding
{variant:2,3,4}8% additional Chance to Block while Dual Wielding
{variant:1,2}(80-120)% increased Physical Damage
{variant:3,4}(100-120)% increased Physical Damage
Adds (55-65) to (100-120) Fire Damage in Main Hand
Adds (55-65) to (100-120) Chaos Damage in Off Hand
Counts as Dual Wielding
]],
}

==> PathOfBuilding-1.4.168.zip: Data/Uniques/axe.lua <==
-- Item data (c) Grinding Gear Games

return {
-- Weapon: One Handed Axe
[[
Dreadarc
Cleaver
Upgrade: Upgrades to unique{Dreadsurge} via prophecy{Burning Dread}
Variant: Pre 2.6.0
Variant: Current
Requires Level 16, 48 Str, 14 Dex
Adds (5-15) to (20-25) Physical Damage
Adds (5-15) to (20-25) Fire Damage
5% increased Movement Speed
(7-10)% Increased Attack Speed
+(15-25)% to Fire Resistance
{variant:1}Curse Enemies with Flammability on Hit
{variant:2}Curse Enemies with level 10 Flammability on Hit
]],[[
Dreadsurge
Cleaver
Source: Upgraded from unique{Dreadarc} via prophecy{Burning Dread}
Requires Level 60, 48 Str, 14 Dex
Adds (5-15) to (20-25) Physical Damage
Adds (223-250) to (264-280) Fire Damage
5% increased Movement Speed
(7-10)% increased Attack Speed
+(15-25)% to Fire Resistance
Hits ignore Enemy Monster Fire Resistance while you are Ignited
]],[[
Dyadus
Infernal Axe
Variant: Pre 2.6.0
Variant: Pre 3.3.0
Variant: Current
Requires Level 69, 158 Str, 76 Dex
{variant:1}Adds (170-190) to (200-220) Fire Damage in Main Hand
{variant:2,3}Adds (255-285) to (300-330) Fire Damage in Main Hand
{variant:1}Adds (170-190) to (200-220) Cold Damage in Off Hand
{variant:2,3}Adds (255-285) to (300-330) Cold Damage in Off Hand
(10-15)% increased Attack Speed
{variant:1}Enemies Chilled by you take 40% increased Burning Damage
{variant:2}Enemies Chilled by you take 100% increased Burning Damage
{variant:3}100% increased Damage with Ignites inflicted on Chilled Enemies
25% Chance to Ignite when in Main Hand
{variant:1}100% increased Chill Duration on Enemies when in Off Hand
{variant:2,3}Chill Enemies for 1 second on Hit with this Weapon when in Off Hand
]],[[
The Screaming Eagle
Jade Hatchet
Upgrade: Upgrades to unique{The Gryphon} via prophecy{The Apex Predator}
Variant: Pre 2.0.0
Variant: Current
Requires Level 6, 21 Str, 10 Dex
{variant:1}Adds (8-12) to (18-22) Physical Damage
{variant:2}Adds (10-15) to (25-30) Physical Damage
+(10-15) to maximum Life
+(5-7) Life gained on Kill
10% increased Movement Speed
Socketed Gems are supported by level 2 Chance to Flee
]],[[
The Gryphon
Jade Hatchet
Source: Upgraded from unique{The Screaming Eagle} via prophecy{The Apex Predator}
Requires Level 32, 21 Str, 10 Dex
Socketed Gems are supported by level 2 Chance to Flee
(170-190)% increased Physical Damage
Adds (10-15) to (25-30) Physical Damage
+(10-15) to maximum Life
+(5-7) Life gained on Kill
10% increased Movement Speed
15% increased Movement Speed if you've Killed Recently
]],[[
Jack, the Axe
Vaal Hatchet
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 65, 140 Str, 86 Dex
(90-110)% increased Physical Damage
Adds (11-14) to (18-23) Physical Damage
(10-15)% increased Attack Speed
2% of Physical Attack Damage Leeched as Life
50% reduced Life Leeched per second
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
]],[[
Moonbender's Wing
Tomahawk
Requires Level 39, 81 Str, 56 Dex
(70-90)% increased Physical Damage
Adds (5-9) to (13-17) Physical Damage
(30-50)% increased Critical Strike Chance
25% of Physical Damage Converted to Cold Damage
25% of Physical Damage Converted to Lightning Damage
Grants level 1 Lightning Warp Skill
]],[[
Relentless Fury
Decorative Axe
Variant: Pre 2.6.0
Variant: Current
Requires Level 29, 80 Str, 23 Dex
(60-80)% increased Physical Damage
Adds (3-5) to (7-10) Physical Damage
{variant:1}0.6% of Physical Attack Damage Leeched as Life
{variant:2}2% of Physical Attack Damage Leeched as Life
Culling Strike
You gain Onslaught for 3 seconds on Culling Strike
Cannot be Chilled while you have Onslaught
]],[[
Rigwald's Savagery
Royal Axe
League: Talisman Standard, Talisman Hardcore
Source: Drops from unique{Rigwald, the Wolven King} (Level 75+)
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 67, 167 Str, 57 Dex
Adds (50-70) to (135-165) Physical Damage
40% increased Physical Weapon Damage while Dual Wielding
(10-15)% increased Attack Speed
35% increased Attack Speed with Swords
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
]],[[
Soul Taker
Siege Axe
Variant: Pre 1.0.0
Variant: Current
Requires Level 59, 119 Str, 82 Dex
{variant:1}(160-200)% increased Physical Damage
{variant:2}(100-140)% increased Physical Damage
Adds 10 to 20 Physical Damage
(20-25)% increased Attack Speed
+(20-25)% to Cold Resistance
Insufficient Mana doesn't prevent your Melee Attacks
Your Physical Damage can Chill
]],
-- Weapon: Two Handed Axe
[[
Atziri's Disfavour
Vaal Axe
Source: Drops from unique{Atziri, Queen of the Vaal} in normal{The Alluring Abyss}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 75, 158 Str, 76 Dex
+2 to Level of Socketed Support Gems
Adds (220-235) to (270-290) Physical Damage
(12-16)% increased Attack Speed
{variant:1}Causes Bleeding on Hit
{variant:2}25% chance to cause Bleeding on Hit
+2 to Weapon range
]],[[
The Blood Reaper
Headsman Axe
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 45, 99 Str, 57 Dex
{variant:1}(100-120)% increased Physical Damage
{variant:2}(180-200)% increased Physical Damage
+100 to maximum Life
10.0 Life Regenerated per second
1% of Physical Attack Damage Leeched as Life
50% increased Mana Cost of Skills
{variant:1}Causes Bleeding on Hit
{variant:2}50% chance to cause Bleeding on Hit
]],[[
Debeon's Dirge
Despot Axe
Requires Level 66, 140 Str, 86 Dex
Adds (310-350) to (460-500) Cold Damage
15% increased Movement Speed if you've used a Warcry Recently
150% increased Elemental Damage if you've used a Warcry Recently
Warcries Knock Enemies Back in an Area
]],[[
The Harvest
Jasper Chopper
League: Beyond
Requires Level 37, 100 Str, 29 Dex
(120-140)% increased Physical Damage
1.2% of Damage Leeched as Life on Critical Strike
3% increased Global Critical Strike Chance per Level
Gain Flask Charges when you deal a Critical Strike
]],[[
Hezmana's Bloodlust
Vaal Axe
Requires Level 64, 158 Str, 76 Dex
(150-170)% increased Physical Damage
Adds (7-12) to (16-25) Physical Damage
1% of Physical Attack Damage Leeched as Life
Attacks have Blood Magic
]],[[
Kaom's Primacy
Karui Chopper
League: Legion
Source: Drops from normal{Karui} legion
Variant: Pre 3.7.0
Variant: Current
Requires Level 58, 151 Str, 43 Dex
(160-220)% increased Physical Damage
{variant:1}Adds (16-21) to (32-38) Fire Damage
+20 Life gained on Kill
+(150-250) to Accuracy Rating
Culling Strike
{variant:2}Gain 1 Rage on Critical Hit with attacks, no more than once every 0.5 seconds
{variant:2}Gain 1% of Physical Damage as Extra Fire Damage per 1 Rage
]],[[
Kingmaker
Despot Axe
Source: Vendor recipe
Variant: Pre 2.6.0
Variant: Current
Requires Level 66, 140 Str, 86 Dex
(200-250)% increased Physical Damage
(7-12)% increased Attack Speed
{variant:2}(30-40)% increased Critical Strike Chance
{variant:1}+(100-150) to maximum Mana
{variant:2}Insufficient Mana doesn't prevent your Melee Attacks
Nearby Allies have 30% increased Item Rarity
{variant:1}Nearby Allies' spells have Culling Strike
{variant:2}Nearby Allies have Culling Strike
]],[[
Kitava's Feast
Void Axe
Variant: Pre 3.5.0
Variant: Current
Requires Level 68, 149 Str, 76 Dex
Socketed Gems are supported by level 25 Melee Splash
{variant:1}(250-300)% increased Physical Damage
{variant:2}(265-330)% increased Physical Damage
1% of Physical Attack Damage Leeched as Life
1% of Physical Attack Damage Leeched as Mana
Recover 5% of Maximum Life on Kill
Enemies you hit are destroyed on Kill
]],[[
Limbsplit
Woodsplitter
Upgrade: Upgrades to unique{The Cauteriser} via prophecy{Severed Limbs}
Requires Level 13, 36 Str, 17 Dex
+1 to Level of Socketed Strength Gems
(80-100)% increased Physical Damage
Adds 5 to 10 Physical Damage
+(15-30) to Strength
Culling Strike
]],[[
The Cauteriser
Woodsplitter
Source: Upgraded from unique{Limbsplit} using prophecy{Severed Limbs}
Requires Level 40, 36 Str, 17 Dex
+1 to Level of Socketed Strength Gems
(80-100)% increased Physical Damage
Adds (35-45) to (80-90) Physical Damage
+(15-30) to Strength
Gain 70% of Physical Damage as Extra Fire Damage
Culling Strike
]],[[
Ngamahu's Flame
Abyssal Axe
Requires Level 55, 128 Str, 60 Dex
(190-230)% increased Physical Damage
(8-12)% increased Attack Speed
50% of Physical Damage Converted to Fire Damage
Damage Penetrates 20% Fire Resistance
20% chance to attack with Level 16 Molten Burst on Melee Hit
]],[[
Reaper's Pursuit
Shadow Axe
Requires Level 33, 80 Str, 37 Dex
(100-125)% increased Physical Damage
+10 Life Gained on Kill
(30-40)% increased Rarity of Items found
15% increased Movement Speed when on Full Life
Culling Strike
Hits can't be Evaded
]],[[
Sinvicta's Mettle
Ezomyte Axe
Requires Level 62, 140 Str, 86 Dex
(200-212)% increased Physical Damage
(8-12)% increased Attack Speed
Rampage
2% increased Area of Effect per 25 Rampage Kills
Gain a Frenzy Charge on every 50th Rampage Kill
]],[[
Uul-Netol's Kiss
Labrys
League: Breach
Source: Drops in Uul-Netol Breach or from unique{Uul-Netol, Unburdened Flesh}
Upgrade: Upgrades to unique{Uul-Netol's Embrace} using currency{Blessing of Uul-Netol}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 49, 122 Str, 53 Dex
(140-170)% increased Physical Damage
15% reduced Attack Speed
25% chance to Curse Enemies with level 10 Vulnerability on Hit
{variant:1}Attacks Cause Bleeding when Hitting Cursed Enemies
{variant:2}Attacks have 25% chance to cause Bleeding when Hitting Cursed Enemies
]],[[
Uul-Netol's Embrace
Vaal Axe
League: Breach
Source: Upgraded from unique{Uul-Netol's Kiss} using currency{Blessing of Uul-Netol}
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 64, 158 Str, 76 Dex
(280-320)% increased Physical Damage
(30-25)% reduced Attack Speed
{variant:1}Attacks Cause Bleeding when Hitting Cursed Enemies
{variant:2}Attacks have 25% chance to cause Bleeding when Hitting Cursed Enemies
Trigger Level 20 Bone Nova when you Kill a Bleeding Enemy
]],[[
Wideswing
Poleaxe
Variant: {2_6}Pre 3.7.0
Variant: Current
Requires Level 18, 44 Str, 25 Dex
Socketed Gems are Supported by level 20 Increased Area of Effect
(120-160)% increased Physical Damage
+10 to Strength
{variant:1}+(50-80) to Accuracy Rating
{variant:2}+(120-150) to Accuracy Rating
+10 Mana Gained on Kill
+2 to Weapon range
]],[[
Wings of Entropy
Sundering Axe
Variant: Pre 1.3.0
Variant: Pre 2.0.0
Variant: {2_6}Pre 3.0.0
Variant: Current
Requires Level 60, 149 Str, 76 Dex
{variant:1,2,3}25% of Block Chance applied to Spells
{variant:4}+7% chance to Block Spell Damage
{variant:1}10% additional Chance to Block while Dual Wielding
{variant:2,3,4}8% additional Chance to Block while Dual Wielding
{variant:1,2}(80-120)% increased Physical Damage
{variant:3,4}(100-120)% increased Physical Damage
Adds (55-65) to (100-120) Fire Damage in Main Hand
Adds (55-65) to (100-120) Chaos Damage in Off Hand
Counts as Dual Wielding
]],
}
